==> NonCompart_0.4.7.tar.gz: NonCompart/inst/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{NonCompart}}
\section{Changes in version 0.4.7 (2020-01-02)}{
  \itemize{
    \item{When impossible to determining slope, it skipe.}
  }
}
\section{Changes in version 0.4.6 (2020-01-02)}{
  \itemize{
    \item{tblNCA supports iAUC argument.}
  }
}
\section{Changes in version 0.4.5 (2019-09-28)}{
  \itemize{
    \item{Some sentences are revised.}
  }
}
\section{Changes in version 0.4.4 (2018-07-20)}{
  \itemize{
    \item{Nonnumeric Subject ID is supported.}
  }
}
\section{Changes in version 0.4.3 (2018-05-17)}{
  \itemize{
    \item{\code{tblNCA} is rewritten.}
  }
}
\section{Changes in version 0.4.2 (2018-05-17)}{
  \itemize{
    \item{Issue on reverse dependence on \code{ncar} is solved.}
  }
}
\section{Changes in version 0.4.1 (2018-04-17)}{
  \itemize{
    \item{Validation document is added.}
    \item{\code{DetSlope} now accepts default slope from \code{BestSlope}.}
    \item{Errata in manual corrected.}
  }
}
\section{Changes in version 0.4.0 (2018-03-17)}{
  \itemize{
    \item{\code{DetSlope} function is added to determine slope manually.}
  }
}
\section{Changes in version 0.3.3 (2017-08-16)}{
  \itemize{
    \item{\pkg{NonCompart} is more tolerable to the input error.}
    \item{\code{sNCA} can accept key of multiple columns instead of single column colSubj.}
  }
}
\section{Changes in version 0.3.2 (2017-07-19)}{
  \itemize{
    \item{\pkg{NonCompart} can handle the case of no or one positive y value.}
  }
}
\section{Changes in version 0.3.1 (2017-07-10)}{
  \itemize{
    \item{\pkg{NonCompart} A bug in C0 calcuation of IV bolus case was fixed.}
  }
}
\section{Changes in version 0.3.0 (2017-04-06)}{
  \itemize{
    \item{\pkg{NonCompart} Only essential functions for calculation were remained.}
  }
}

==> NonCompart_0.4.8.tar.gz: NonCompart/inst/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{NonCompart}}
\section{Changes in version 0.4.8 (2021-06-10)}{
  \itemize{
    \item{UT function removed}
    \item{returnNA option in sNCA function is removed.}
  }
}
\section{Changes in version 0.4.7 (2020-01-02)}{
  \itemize{
    \item{When impossible to determining slope, it skipe.}
  }
}
\section{Changes in version 0.4.6 (2020-01-02)}{
  \itemize{
    \item{tblNCA supports iAUC argument.}
  }
}
\section{Changes in version 0.4.5 (2019-09-28)}{
  \itemize{
    \item{Some sentences are revised.}
  }
}
\section{Changes in version 0.4.4 (2018-07-20)}{
  \itemize{
    \item{Nonnumeric Subject ID is supported.}
  }
}
\section{Changes in version 0.4.3 (2018-05-17)}{
  \itemize{
    \item{\code{tblNCA} is rewritten.}
  }
}
\section{Changes in version 0.4.2 (2018-05-17)}{
  \itemize{
    \item{Issue on reverse dependence on \code{ncar} is solved.}
  }
}
\section{Changes in version 0.4.1 (2018-04-17)}{
  \itemize{
    \item{Validation document is added.}
    \item{\code{DetSlope} now accepts default slope from \code{BestSlope}.}
    \item{Errata in manual corrected.}
  }
}
\section{Changes in version 0.4.0 (2018-03-17)}{
  \itemize{
    \item{\code{DetSlope} function is added to determine slope manually.}
  }
}
\section{Changes in version 0.3.3 (2017-08-16)}{
  \itemize{
    \item{\pkg{NonCompart} is more tolerable to the input error.}
    \item{\code{sNCA} can accept key of multiple columns instead of single column colSubj.}
  }
}
\section{Changes in version 0.3.2 (2017-07-19)}{
  \itemize{
    \item{\pkg{NonCompart} can handle the case of no or one positive y value.}
  }
}
\section{Changes in version 0.3.1 (2017-07-10)}{
  \itemize{
    \item{\pkg{NonCompart} A bug in C0 calcuation of IV bolus case was fixed.}
  }
}
\section{Changes in version 0.3.0 (2017-04-06)}{
  \itemize{
    \item{\pkg{NonCompart} Only essential functions for calculation were remained.}
  }
}
